@@ -30,6 +30,16 @@ def calculate_iqr_of_column(dataframe: DataFrame, column_label: str) -> float:
     return q3 - q1
 
 
+def calculate_missing_value_statistics(dataframe: DataFrame):
+    missing_stats_dataframe = DataFrame(
+        {
+            'Missing': dataframe.isnull().sum(),
+            '% Missing': dataframe.isnull().sum() / len(dataframe)
+        })
+    missing_stats_dataframe = missing_stats_dataframe[missing_stats_dataframe['Missing'] > 0]
+    return missing_stats_dataframe.sort_values(by='Missing', ascending=False)
+
+
 def calculate_outlier_limits(dataframe: DataFrame, column_label: str) -> tuple:
     """
     Calculate the limits of outliers
